package com.xylink.sdk.device;

import com.fasterxml.jackson.core.type.TypeReference;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.xylink.config.SDKConfigMgr;
import com.xylink.model.DeviceInfo;
import com.xylink.model.DeviceInfoDetail;
import com.xylink.model.Pager;
import com.xylink.util.HttpUtil;
import com.xylink.util.Result;
import com.xylink.util.SignatureSample;
import org.apache.commons.lang3.StringUtils;

import java.io.IOException;
import java.util.List;

/**
 * Created by maolizhi on 12/15/2016.
 * Nemo(Device) Status API
 */
public class DeviceStatusApi {
    private static SignatureSample signatureSample = new SignatureSample();
    private static final String prefixUrl = "/api/rest/external/v1/deviceInfo";
    private static final ObjectMapper objectMapper = new ObjectMapper();

    /**
     * get one nemo status according to nemoNumber,if Result Object's success is true,the "data" type of Result is DeviceInfo;if not, the "data" type of Result is RestMessage
     * @param enterpriseId
     * @param token
     * @param number
     * @return
     * @throws IOException
     */
    public Result<DeviceInfo> getDeviceInfo(String enterpriseId,String token,String number) throws IOException{

        String surl = getPrefixUrl(enterpriseId) + "/" + number + "?enterpriseId=" + enterpriseId;
        String signature = signatureSample.computeSignature("","GET",token,surl);
        surl += "&signature=" + signature;
        return HttpUtil.getResponse(surl,"GET", null,DeviceInfo.class);

    }

    public Result<DeviceInfoDetail> getDeviceInfoDetail(String enterpriseId, String token, String number) throws IOException{

        String surl = getPrefixUrl(enterpriseId) + "/" + number + "/detail?enterpriseId=" + enterpriseId;
        String signature = signatureSample.computeSignature("","GET",token,surl);
        surl += "&signature=" + signature;
        return HttpUtil.getResponse(surl,"GET", null,DeviceInfoDetail.class);

    }

    /**
     * get all nemo status in the enterprise,if Result Object's success is true,the "data" type of Result is DeviceInfo[];if not, the "data" type of Result is RestMessage
     * @param enterpriseId
     * @param token
     * @return
     * @throws IOException
     */
    @Deprecated
    public Result<DeviceInfo[]> getDeviceInfo(String enterpriseId,String token) throws IOException{

        String surl = getPrefixUrl(enterpriseId)  + "?enterpriseId=" + enterpriseId;
        String signature = signatureSample.computeSignature("","GET",token,surl);
        surl += "&signature=" + signature;
        return HttpUtil.getResponse(surl,"GET", null,DeviceInfo[].class);

    }

    public Result<Pager<DeviceInfo>> getDeviceInfo(String enterpriseId,String token, int page, int size) throws IOException{

        String surl = getPrefixUrl(enterpriseId)  + "/page?enterpriseId=" + enterpriseId + "&pageIndex=" + page + "&pageSize=" + size;
        String signature = signatureSample.computeSignature("","GET",token,surl);
        surl += "&signature=" + signature;
        Result<String> resp = HttpUtil.getResponse(surl,"GET", null, String.class);
        Result<Pager<DeviceInfo>> result = new Result<Pager<DeviceInfo>>();
        result.setSuccess(resp.isSuccess());
        result.setErrorStatus(resp.getErrorStatus());
        result.setErrorMsg(resp.getErrorMsg());

        if (resp.isSuccess() && StringUtils.isNotBlank(resp.getData())) {
            ObjectMapper objectMapper = new ObjectMapper();
            Pager<DeviceInfo> pager = objectMapper.readValue(resp.getData(), new TypeReference<Pager<DeviceInfo>>() {});
            result.setData(pager);
        }

        return result;

    }

    /**
     * 根据小鱼SN列表获取小鱼信息，所有的sn必须已经导入企业管理平台
     * @param enterpriseId
     * @param token
     * @param snList
     * @return
     * @throws IOException
     */
    public Result<DeviceInfo[]> getDeviceInfo(String enterpriseId, String token, List<String> snList) throws IOException {
        if(snList == null || snList.size() <= 0) {
            return null;
        }
        String surl = getPrefixUrl(enterpriseId)  + "?enterpriseId=" + enterpriseId;
        String jsonEntity = objectMapper.writeValueAsString(snList);
        String signature = signatureSample.computeSignature(jsonEntity, "PUT", token, surl);
        surl += "&signature=" + signature;
        return HttpUtil.getResponse(surl, "PUT", jsonEntity, DeviceInfo[].class);
    }

    private String getPrefixUrl(String enterpriseId) {
        return SDKConfigMgr.getServerHost(enterpriseId) + prefixUrl;
    }
}
