package com.xylink.sdk.vod;

import com.xylink.config.SDKConfigMgr;
import com.xylink.model.ThumbnailurlInfo;
import com.xylink.model.LiveVodInfo;
import com.xylink.model.VodInfo;
import com.xylink.util.HttpUtil;
import com.xylink.util.Result;
import com.xylink.util.SignatureSample;

import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.Map;


/**
 * Created by maolizhi on 12/18/2016.
 */
public class VodApi {
    private static SignatureSample signatureSample = new SignatureSample();
    private static final String prefixUrl = "/api/rest/external/v1/";

    /**
     * get all videos int the day,startTime is greater than 0,startTime is less than endTime,
     * endTime-startTime is less than the millisecond number of one day.
     * @param enterpriseId
     * @param token
     * @param startTime
     * @param endTime
     * @return
     * @throws IOException
     */
    @Deprecated
    public Result getVods(String enterpriseId, String token,long startTime,long endTime)throws IOException{
        String surl = getPrefixUrl(enterpriseId)  + "vods?enterpriseId=" + enterpriseId + "&startTime=" + startTime + "&endTime="
                + endTime;
        String signature = signatureSample.computeSignature("","GET",token,surl);
        surl += "&signature=" + signature;
        return HttpUtil.getResponse(surl,"GET", null,String.class);
    }

    /**
     * get the nemo's all videos, if startTime is less than or equal to 0,return the nemo's all videos,ignore endTime;
     * if startTime is greater than 0 ,the endTime must be bigger than the startTime;there is no other limits for
     * startTime and endTime
     * @param enterpriseId
     * @param token
     * @param nemoNumber
     * @param startTime
     * @param endTime
     * @return
     * @throws IOException
     */
    @Deprecated
    public Result<VodInfo[]> getNemoVods(String enterpriseId, String token,String nemoNumber,long startTime,
                              long endTime)throws IOException{
        String surl = getPrefixUrl(enterpriseId)  + "nemo/"+nemoNumber+"/vods?enterpriseId=" + enterpriseId +
                "&startTime="+startTime+"&endTime="+endTime;
        String signature = signatureSample.computeSignature("","GET",token,surl);
        surl += "&signature=" + signature;
        return HttpUtil.getResponse(surl,"GET", null,VodInfo[].class);
    }

    /**
     * get all videos for the meeting room during the time ,the time limits is same as the method of
     * getNemoVods
     * @param enterpriseId
     * @param token
     * @param meetingRoomNumber
     * @param startTime
     * @param endTime
     * @return
     * @throws IOException
     */
    @Deprecated
    public Result<VodInfo[]> getMeetingRoomVods(String enterpriseId, String token,String meetingRoomNumber,Long startTime,
                              Long endTime)throws IOException{
        String surl = getPrefixUrl(enterpriseId)  + "meetingroom/" + meetingRoomNumber + "/vods?enterpriseId=" + enterpriseId;
        if (startTime != null) {
            surl += "&startTime="+startTime;
        }
        if (endTime != null) {
            surl += "&endTime="+endTime;
        }
        String signature = signatureSample.computeSignature("","GET",token,surl);
        surl += "&signature=" + signature;
        return HttpUtil.getResponse(surl,"GET", null,VodInfo[].class);
    }

    /**
     * get video default thumbnail according to video id,
     * if success,the data type of result is byte[]; if failed ,the data type of result is
     * RestMessage. If success,you can convert the byte[] to image file.
     *
     * 已废弃，请使用getVodThumbnailurl
     *
     * @param enterpriseId
     * @param token
     * @param vodId
     * @return
     * @throws IOException
     */
    @Deprecated
    public Result getVodThumbnail(String enterpriseId, String token,String vodId)throws IOException{
        String surl = getPrefixUrl(enterpriseId)  + "vods/"+ vodId+ "/thumbnail?enterpriseId=" + enterpriseId ;
        String signature = signatureSample.computeSignature("","GET",token,surl);
        surl += "&signature=" + signature;
        return HttpUtil.getByteStreamResponse(surl,"GET", null);
    }

    /**
     * 获得企业某个会议室的视频列表
     *
     * @param enterpriseId
     * @param token
     * @param vodId
     * @return
     * @throws IOException
     */
    public Result getVodThumbnailurl(String enterpriseId, String token,String vodId)throws IOException{
        String surl = getPrefixUrl(enterpriseId)  + "vods/"+ vodId+ "/thumbnailurl?enterpriseId=" + enterpriseId ;
        String signature = signatureSample.computeSignature("","GET",token,surl);
        surl += "&signature=" + signature;
        return HttpUtil.getResponse(surl,"GET", null,ThumbnailurlInfo.class);
    }

    /**
     * convert byte array to image or video
     * @param bytes
     * @param path
     */
    public void convertByteArrayToImageOrVideo(byte[] bytes,String path){
        FileOutputStream fos = null;
        try {
            fos = new FileOutputStream(path);
            fos.write(bytes);
        } catch (FileNotFoundException e) {
            System.out.println("File Path not found!");
        } catch (IOException e) {
            System.out.println("Convert byte array to image,IO Errot!");
        }

    }

    /**
     * download the video according to video id
     * if success,the data type of result is byte[]; if failed ,the data type of result is
     * RestMessage. If success,you can call  convertByteArrayToImageOrVideo(byte[] bytes,String path)
     * convert the byte[] to video file.
     * @param enterpriseId
     * @param token
     * @param vodId
     * @return
     * @throws IOException
     */
    @Deprecated
    public Result videoDownload(String enterpriseId, String token,String vodId)throws IOException{
        String surl = getPrefixUrl(enterpriseId)  + "vods/"+ vodId+ "/download?enterpriseId=" + enterpriseId ;
        String signature = signatureSample.computeSignature("","GET",token,surl);
        surl += "&signature=" + signature;
        return HttpUtil.getByteStreamResponse(surl,"GET", null);
    }

    /**
     * delete the video according to video id
     * @param enterpriseId
     * @param token
     * @param vodId
     * @return
     * @throws IOException
     */
    public  Result deleteVideo(String enterpriseId, String token,String vodId)throws IOException{
        String surl = getPrefixUrl(enterpriseId)  + "vods/"+ vodId+ "?enterpriseId=" + enterpriseId ;
        String signature = signatureSample.computeSignature("","DELETE",token,surl);
        surl += "&signature=" + signature;
        return HttpUtil.getResponse(surl,"DELETE", null,null);
    }

    /**
     * delete the video according to conference number
     * @param enterpriseId .
     * @param token .
     * @param meetingRoomNumber .
     * @return .
     * @throws IOException .
     */
    public Result deleteMeetingRoomVods(String enterpriseId, String token, String meetingRoomNumber)throws IOException{
        String surl = getPrefixUrl(enterpriseId)  + "meetingroom/" + meetingRoomNumber + "/vods?enterpriseId=" + enterpriseId ;
        String signature = signatureSample.computeSignature("","DELETE",token,surl);
        surl += "&signature=" + signature;
        return HttpUtil.getResponse(surl,"DELETE", null,null);
    }

    /**
     * get the download url for the video according to video id
     * @param enterpriseId
     * @param token
     * @param vodId
     * @return
     * @throws IOException
     */
    public Result getDownloadurl(String enterpriseId, String token, String vodId)throws IOException{
        String surl = getPrefixUrl(enterpriseId)  + "vods/"+ vodId+ "/getdownloadurl?enterpriseId=" + enterpriseId ;
        String signature = signatureSample.computeSignature("","GET",token,surl);
        surl += "&signature=" + signature;
        return HttpUtil.getResponse(surl,"GET", null, Map.class);
    }

    /**
     * get the download url for the video according to session id
     * @param enterpriseId
     * @param token
     * @param sessionId
     * @return
     * @throws IOException
     */
    public Result getDownloadurlBySessionId(String enterpriseId, String token, String sessionId)throws IOException{
        String surl = getPrefixUrl(enterpriseId)  + "vods/session/"+ sessionId+ "/downloadurl?enterpriseId=" + enterpriseId ;
        String signature = signatureSample.computeSignature("","GET",token,surl);
        surl += "&signature=" + signature;
        return HttpUtil.getResponse(surl,"GET", null, Map.class);
    }


    public Result getDownloadurlBySessionId(String enterpriseId, String token, String sessionId, String publicKey)throws IOException{
        String surl = getPrefixUrl(enterpriseId)  + "vods/session/"+ sessionId+ "/downloadurl?enterpriseId=" + enterpriseId+"&publicKey="+publicKey ;
        String signature = signatureSample.computeSignature("","GET",token,surl);
        surl += "&signature=" + signature;
        return HttpUtil.getResponse(surl,"GET", null, Map.class);
    }


    /**
     * 根据终端号分页查询视频列表
     * @param enterpriseId
     * @param token
     * @param nemoNumber
     * @param startTime
     * @param endTime
     * @param pageIndex
     * @param pageSize
     * @return
     * @throws IOException
     */
    public Result getNemoDeviceVodsPage(String enterpriseId, String token,String nemoNumber, long startTime,long endTime,int pageIndex,int pageSize)throws IOException{
        String surl = getPrefixUrl(enterpriseId)  + "nemo/"+nemoNumber+"/vods/page?enterpriseId="+enterpriseId+"&startTime="+startTime+"&endTime="+ endTime+"&pageIndex="+pageIndex+"&pageSize="+pageSize;
        String signature = signatureSample.computeSignature("","GET",token,surl);
        surl += "&signature=" + signature;
        return HttpUtil.getResponse(surl,"GET", null, Map.class);
    }

    /**
     * 分页查询云会议室下视频列表
     * @param enterpriseId
     * @param token
     * @param meetingRoomNumber
     * @param startTime
     * @param endTime
     * @param pageIndex
     * @param pageSize
     * @return
     * @throws IOException
     */
    public Result getMeetingRoomVodsPage(String enterpriseId, String token,String meetingRoomNumber, long startTime,long endTime,int pageIndex,int pageSize)throws IOException{
        String surl = getPrefixUrl(enterpriseId)  + "meetingroom/"+meetingRoomNumber+"/vods/page?enterpriseId="+enterpriseId+"&startTime="+startTime+"&endTime="+ endTime+"&pageIndex="+pageIndex+"&pageSize="+pageSize;
        String signature = signatureSample.computeSignature("","GET",token,surl);
        surl += "&signature=" + signature;
        return HttpUtil.getResponse(surl,"GET", null, Map.class);
    }

    /**
     * 分页查询企业下一段时间内的视频列表（一天之内）
     * @param enterpriseId
     * @param token
     * @param startTime
     * @param endTime
     * @param pageIndex
     * @param pageSize
     * @return
     * @throws IOException
     */
    public Result getEnterpriseVodsPage(String enterpriseId, String token, long startTime,long endTime,int pageIndex,int pageSize)throws IOException{
        String surl = getPrefixUrl(enterpriseId) + "vods/page?enterpriseId="+enterpriseId+"&startTime="+startTime+"&endTime="+ endTime+"&pageIndex="+pageIndex+"&pageSize="+pageSize;
        String signature = signatureSample.computeSignature("","GET",token,surl);
        surl += "&signature=" + signature;
        return HttpUtil.getResponse(surl,"GET", null, Map.class);
    }

    /**
     * 获取视频分享链接 链接永久有限 不存在过期
     * @param vodId
     * @param token
     * @param enterpriseId
     * @return
     * @throws IOException
     */
    public Result getVodSharedInfo(String vodId, String token,String enterpriseId)throws IOException{
        String surl = getPrefixUrl(enterpriseId)  + "vods/"+vodId+"/sharedInfo?enterpriseId="+enterpriseId;
        String signature = signatureSample.computeSignature("","GET",token,surl);
        surl += "&signature=" + signature;
        return HttpUtil.getResponse(surl,"GET", null, Map.class);
    }

    /**
     * 可以指定过期时间（最短） 获取视频分享链接
     * @param vodId
     * @param token
     * @param enterpriseId
     * @param linkExpireSec 过期时间（秒：最短一个小时 即3600s）
     * @return
     * @throws IOException
     */
    public Result getVodSharedInfoByExpire(String vodId, String token,String enterpriseId,Integer linkExpireSec)throws IOException{
        String surl = getPrefixUrl(enterpriseId)  + "vods/"+vodId+"/sharedInfo?enterpriseId="+enterpriseId+"&linkExpireSec="+linkExpireSec;
        String signature = signatureSample.computeSignature("","GET",token,surl);
        surl += "&signature=" + signature;
        return HttpUtil.getResponse(surl,"GET", null, Map.class);
    }

    /**
     * 根据直播id查询视频列表
     * @param enterpriseId
     * @param token
     * @param liveId
     * @return
     * @throws IOException
     */
    public Result getVodsByLiveId(String enterpriseId, String token,String liveId)throws IOException{
        String surl = getPrefixUrl(enterpriseId)  + "vods/" + liveId + "/query?enterpriseId=" + enterpriseId;
        String signature = signatureSample.computeSignature("","GET",token,surl);
        surl += "&signature=" + signature;
        return HttpUtil.getResponse(surl,"GET", null, LiveVodInfo[].class);
    }

    /**
     * 根据meetingId分页查询录制视频列表
     * @param enterpriseId
     * @param token
     * @param meetingRoomNumber
     * @param meetingId
     * @param pageIndex
     * @param pageSize
     * @return
     * @throws IOException
     */
    public Result getMeetingRoomVodsByMeetingId(String enterpriseId, String token,String meetingRoomNumber,String meetingId,int pageIndex,int pageSize)throws IOException{
        String surl = getPrefixUrl(enterpriseId)  + "meetingroom/" + meetingRoomNumber +"/"+meetingId+ "/vods?enterpriseId=" + enterpriseId+"&pageIndex="+pageIndex+"&pageSize="+pageSize;
        String signature = signatureSample.computeSignature("","GET",token,surl);
        surl += "&signature=" + signature;
        return HttpUtil.getResponse(surl,"GET", null,Map.class);
    }

    private String getPrefixUrl(String enterpriseId) {
        return SDKConfigMgr.getServerHost(enterpriseId) + prefixUrl;
    }
}
