package com.xylink.user;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.xylink.config.SDKConfigMgr;
import com.xylink.model.BuffetUserDto;
import com.xylink.model.Pager;
import com.xylink.util.HttpUtil;
import com.xylink.util.Result;
import com.xylink.util.SignatureSample;
import java.io.IOException;
import java.util.List;
import java.util.Map;
import java.util.Set;

/**
 * Created by changxiangyang on 2017/10/31.
 */
@JsonIgnoreProperties(ignoreUnknown = true)
public class BuffetUserApi {
    private static SignatureSample signatureSample = new SignatureSample();
    private static final String prefixUrl = "/api/rest/external/v1/buffet/";

    /**
     * batch addition User Info
     * @param buffetUserDtos UserList
     * @param enterpriseId
     * @param token
     * @return
     * @throws IOException
     */
    public Result<Set> batchAdd(List<BuffetUserDto> buffetUserDtos, String enterpriseId, String token) throws IOException {
        String surl = getPrefixUrl(enterpriseId) + "batch/users?enterpriseId=" + enterpriseId;
        String jsonEntity = new ObjectMapper().writeValueAsString(buffetUserDtos);
        String signature = signatureSample.computeSignature(jsonEntity, "POST", token, surl);
        surl += "&signature=" + signature;
        return HttpUtil.getResponse(surl, "POST", jsonEntity, Set.class);
    }

    /**
     * add user
     * @param buffetUserDtos
     * @param enterpriseId
     * @param token
     * @return
     * @throws IOException
     */
    public Result<Map> add(BuffetUserDto buffetUserDtos, String enterpriseId, String token) throws IOException {
        String surl = getPrefixUrl(enterpriseId) + "user?enterpriseId=" + enterpriseId;
        String jsonEntity = new ObjectMapper().writeValueAsString(buffetUserDtos);
        String signature = signatureSample.computeSignature(jsonEntity, "POST", token, surl);
        surl += "&signature=" + signature;
        return HttpUtil.getResponse(surl, "POST", jsonEntity, Map.class);
    }

    /**
     * 单邮箱用户加入企业
     * @param enterpriseId
     * @param token
     * @param buffetUserDto
     * @return
     * @throws IOException
     */
    public Result<Map> addMailUser(String enterpriseId, String token,BuffetUserDto buffetUserDto) throws IOException {
        String surl = getPrefixUrl(enterpriseId) + "mail/user?enterpriseId=" + enterpriseId;
        String jsonEntity = new ObjectMapper().writeValueAsString(buffetUserDto);
        String signature = signatureSample.computeSignature(jsonEntity, "POST", token, surl);
        surl += "&signature=" + signature;
        return HttpUtil.getResponse(surl, "POST", jsonEntity, Map.class);
    }

    /**
     * 单邮箱用户移除企业
     * @param enterpriseId
     * @param token
     * @param email
     * @return
     * @throws IOException
     */
    public Result<Map> removeMailUser(String enterpriseId, String token,String email) throws IOException {
        String surl = getPrefixUrl(enterpriseId) + "mail/user?enterpriseId=" + enterpriseId+"&email="+email;
        String signature = signatureSample.computeSignature("", "DELETE", token, surl);
        surl += "&signature=" + signature;
        return HttpUtil.getResponse(surl, "DELETE", "", Map.class);
    }

    /**
     * 根据手机号或邮箱获取用户信息
     * @param enterpriseId
     * @param token
     * @param buffetUserDto
     * @return
     * @throws IOException
     */
    public Result<Map> getUserInfoByMailOrPhone(String enterpriseId, String token,BuffetUserDto buffetUserDto) throws IOException {
        String surl = getPrefixUrl(enterpriseId) + "user/query?enterpriseId=" + enterpriseId;
        String jsonEntity = new ObjectMapper().writeValueAsString(buffetUserDto);
        String signature = signatureSample.computeSignature(jsonEntity, "PUT", token, surl);
        surl += "&signature=" + signature;
        return HttpUtil.getResponse(surl, "PUT", jsonEntity, Map.class);
    }


    /**
     * get user info
     * @param enterpriseId
     * @param token
     * @return
     * @throws IOException
     */
    @Deprecated
    public Result<List> get(String enterpriseId, String token) throws IOException {
        String surl = getPrefixUrl(enterpriseId) + "user?enterpriseId=" + enterpriseId;
        String signature = signatureSample.computeSignature("", "GET", token, surl);
        surl += "&signature=" + signature;
        return HttpUtil.getResponse(surl, "GET", null, List.class);
    }

    /**
     * get user info by page
     * @param enterpriseId
     * @param token
     * @return
     * @throws IOException
     */
    public Result<Pager> getUserInfoByPage(String enterpriseId, String token, Integer pageIndex, Integer pageSize) throws IOException {
        String surl = getPrefixUrl(enterpriseId) + "user/page?enterpriseId="+enterpriseId+"&pageIndex="+pageIndex+"&pageSize="+pageSize;
        String signature = signatureSample.computeSignature("", "GET", token, surl);
        surl += "&signature=" + signature;
        return HttpUtil.getResponse(surl, "GET", null, Pager.class);
    }

    /**
     * update user info
     * @param buffetUserDtos
     * @param enterpriseId
     * @param token
     * @return
     * @throws IOException
     */
    public Result update(BuffetUserDto buffetUserDtos, String enterpriseId, String token) throws IOException {
        String surl = getPrefixUrl(enterpriseId) + "user?enterpriseId=" + enterpriseId;
        String jsonEntity = new ObjectMapper().writeValueAsString(buffetUserDtos);
        String signature = signatureSample.computeSignature(jsonEntity, "PUT", token, surl);
        surl += "&signature=" + signature;
         return HttpUtil.getResponse(surl, "PUT", jsonEntity, null);

    }

    /**
     * delete user
     * @param enterpriseId
     * @param token
     * @return
     * @throws IOException
     */
    public Result delete( String enterpriseId,String countryCode, String phone, String token) throws IOException {
        String surl = getPrefixUrl(enterpriseId) + "user?countryCode=" + countryCode + "&phone=" + phone + "&enterpriseId=" + enterpriseId;
        String signature = signatureSample.computeSignature("", "DELETE", token, surl);
        surl += "&signature=" + signature;
        return HttpUtil.getResponse(surl, "DELETE", null, null);
    }


    private String getPrefixUrl(String enterpriseId) {
        return SDKConfigMgr.getServerHost(enterpriseId) + prefixUrl;
    }
}
