package com.xylink.sdk.test;

import com.xylink.config.SDKConfigMgr;
import com.xylink.model.MeetingInfo;
import com.xylink.model.Pager;
import com.xylink.model.SdkCloudMeetingRoomRequest;
import com.xylink.model.SdkMeeting;
import com.xylink.model.SdkMeetingReq;
import com.xylink.sdk.conferenceControl.CreateMeetingApi;
import com.xylink.util.Result;
import com.xylink.util.SignUtil;
import org.junit.BeforeClass;
import org.junit.FixMethodOrder;
import org.junit.Test;
import org.junit.runners.MethodSorters;

import javax.xml.transform.Source;
import java.io.IOException;
import java.util.HashMap;
import java.util.Map;

import static org.junit.Assert.*;

/**
 * Created by changxiangyang on 2017/9/19.
 */
@FixMethodOrder(MethodSorters.NAME_ASCENDING)
public class CreateMeetingTest extends EnterpriseConfig{


    //创建会议 TODO 会议室号不能重复
    @Test
    public void createMeeting(){
        CreateMeetingApi cma=new CreateMeetingApi();
        SdkMeetingReq smr=new SdkMeetingReq();
        smr.setMeetingName("room1");
        smr.setStartTime(System.currentTimeMillis() + (1000 * 60 * 2));
        smr.setDuration(1000 * 6000);
        smr.setMaxParticipantCount(5);
        smr.setAutoRecord(true);
        smr.setAutoMute(1);
//        smr.setMeetingNumber("910087653908");
//        smr.setRequirePassword(true);
//        smr.setPassword("090909");
        try {
            SdkMeeting meeting = cma.createMeeting(enterpriseId, token, smr);
            System.out.println(meeting);
            meetingRoomNumber = meeting.getMeetingNumber();
        }catch (Exception e){
            System.out.println("testgetMeetingStatus--"+e);
        }
    }

    //创建会议
    @Test
    public void createMeetingV2(){
        CreateMeetingApi cma=new CreateMeetingApi();
        SdkCloudMeetingRoomRequest sdkCloudMeetingRoomRequest=new SdkCloudMeetingRoomRequest();
        sdkCloudMeetingRoomRequest.setMeetingName("room1-dddd");
        sdkCloudMeetingRoomRequest.setStartTime(System.currentTimeMillis() + (1000 * 60 * 2));
        sdkCloudMeetingRoomRequest.setEndTime(System.currentTimeMillis() + (1000 * 60 * 20));
        sdkCloudMeetingRoomRequest.setMaxParticipant(4);
        sdkCloudMeetingRoomRequest.setAutoMute(0);
        sdkCloudMeetingRoomRequest.setMaxSharedSession(4);
        Map<String, String> configs = new HashMap<String, String>();
        configs.put("autoRecord", "false");
        configs.put("recordAddDeviceName", "true");
        configs.put("smartMutePerson", "3");
        sdkCloudMeetingRoomRequest.setConfigs(configs);

        try {
            SdkMeeting meeting = cma.createMeetingV2(enterpriseId, token, sdkCloudMeetingRoomRequest);
            System.out.println(meeting);
            meetingRoomNumber = meeting.getMeetingNumber();
            // 成功示例：SdkMeeting{meetingNumber='910056972431', controlPassword='125102', password='', shareUrl='http://sdk.xylink.com/page/third/KUUSKTJC'}
        }catch (Exception e){
            System.out.println("testgetMeetingStatus--"+e);
        }
    }

    //创建会议
    @Test
    public void createMeetingByType(){

        CreateMeetingApi cma=new CreateMeetingApi();
        SdkCloudMeetingRoomRequest sdkCloudMeetingRoomRequest=new SdkCloudMeetingRoomRequest();
        sdkCloudMeetingRoomRequest.setMeetingName("testMeetingByType");
        sdkCloudMeetingRoomRequest.setRequirePassword(true);
        sdkCloudMeetingRoomRequest.setPassword("123456");
        sdkCloudMeetingRoomRequest.setControlPassword("123456");
        sdkCloudMeetingRoomRequest.setAutoMute(0);
        Map<String, String> configs = new HashMap<String, String>();
        configs.put("autoRecord", "false");
        configs.put("recordAddDeviceName", "false");
        configs.put("onlyRecordMainImage", "false");
        configs.put("smartMutePerson", "3");
        sdkCloudMeetingRoomRequest.setConfigs(configs);

        try {
            SdkMeeting meeting = cma.createMeetingByType(enterpriseId, token, sdkCloudMeetingRoomRequest);
            System.out.println(meeting);
            meetingRoomNumber = meeting.getMeetingNumber();
            // 成功示例：SdkMeeting{meetingNumber='910056972431', controlPassword='125102', password='', shareUrl='http://sdk.xylink.com/page/third/KUUSKTJC'}
        }catch (Exception e){
            System.out.println("testcreateMeetingByType--"+e);
        }
    }

    //按照会议号查询会议信息 TODO 云会议号保证有效
    @Test
    public void getMeetingInfo(){

        CreateMeetingApi cma=new CreateMeetingApi();

        Result<MeetingInfo> result=null;
        try {
            result=cma.getMeetingInfo(enterpriseId, token, meetingRoomNumber);
            System.out.println(result);
        }catch (IOException e){
            e.printStackTrace();
            fail(e.getMessage());
        }
    }
    //修改会议信息 TODO 云会议号保证有效
    @Test
    public void updateMeetingInfo(){

        CreateMeetingApi cma=new CreateMeetingApi();
        MeetingInfo meetingInfo=new MeetingInfo();
//        meetingInfo.setAutoMute(1);
//        meetingInfo.setSmartMutePerson(3);
        meetingInfo.setExpireTime(1619521247000l);
        meetingInfo.setSmartMutePerson(6);
        try {
            Result result = cma.updateMeetingInfo(enterpriseId, token, meetingRoomNumber, meetingInfo);
            System.out.println("update result:"+result);
//            assertEquals(200, result.getErrorStatus());
        }catch (IOException e){
            fail(e.getMessage());
        }
        try {
            Result<MeetingInfo> result = cma.getMeetingInfo(enterpriseId, token, meetingRoomNumber);
            System.out.println("更新后查询到的云会议室：" + result);
//            meetingInfo = result.getData();
//            assertEquals(result.getData().getAutoMute(), 2);
//            assertFalse(result.getData().isAutoRecord());
        } catch (IOException e) {
            fail(e.getMessage());
        }

    }
    //批量查询会议信息 TODO 云会议号保证有效
    @Test
    public void getBatchMeetingInfo(){
        CreateMeetingApi cma=new CreateMeetingApi();
        String [] meetingRoomNos={meetingRoomNumber};
        try {
            Result<MeetingInfo[]> batchMeetingInfo = cma.getBatchMeetingInfo(enterpriseId, token, meetingRoomNos);
            System.out.println(batchMeetingInfo);
        }catch (IOException e){
            System.out.println("testGetBatchMeetingInfo--"+e);
        }
    }
    //删除会议 TODO 云会议号保证有效
    @Test
    public void xdeleteMeetingInfo(){

        CreateMeetingApi cma=new CreateMeetingApi();
        try {
            Result result= cma.deleteMeetingInfo(enterpriseId, token, meetingRoomNumber);
            System.out.println(result);
        }catch (IOException e){
            fail(e.getMessage());
        }
    }

    //查询某公司的sdk创建的会议
    @Test
    public void getSdkMeetingRooms(){
        CreateMeetingApi cma=new CreateMeetingApi();
        try {
            Result<MeetingInfo[]> sdkMeetingRooms = cma.getSdkMeetingRooms(enterpriseId, token);
            System.out.println(sdkMeetingRooms);
        }catch (IOException e){
            fail(e.getMessage());
        }
    }
    @Test
    public void getMeetingRoomsByType(){
        CreateMeetingApi cma=new CreateMeetingApi();
        try {
            Result result = cma.getMeetingRoomsByType(enterpriseId, token,0,10,"ENTERPRISE_CONFERENCE");
            System.out.println(result);
        }catch (IOException e){
            fail(e.getMessage());
        }
    }

    @Test
    public void getSdkMeetingRoomsByPage(){
        CreateMeetingApi cma=new CreateMeetingApi();
        int page = 0;
        int size = 20;
        try {
            Result<Pager<MeetingInfo>> sdkMeetingRooms = cma.getSdkMeetingRooms(enterpriseId, token, page, size);
            System.out.println(sdkMeetingRooms);
        }catch (IOException e){
            fail(e.getMessage());
        }
    }
}
