package com.xylink.sdk.不要外发;

import com.google.common.base.Predicate;
import com.xylink.config.EnterpriseSdkConfig;
import com.xylink.config.SDKConfig;
import com.xylink.config.SDKConfigMgr;
import com.xylink.config.SignatureVersion;
import com.xylink.log.XyLinkLogType;
import com.xylink.model.MeetingStatus;
import com.xylink.sdk.SdkMethodV1;
import com.xylink.sdk.SdkMethodV2;
import com.xylink.sdk.conferenceControl.ConferenceControlApi;
import com.xylink.util.Result;
import com.xylink.util.SchedulerUtil;
import org.junit.Test;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.concurrent.TimeUnit;

/**
 * @Classname RefactorTest
 * @Date 2023/6/20 4:18 PM
 * @Created by anan
 * @Description description here
 */
public class RefactorTest {

    /**
     * 单独配置，使用sdk通用方法，这个没法使用v2，因为没有初始化数据
     * @throws IOException
     */
    @Test
    public void testSingleConfigWithSdkMethod() throws IOException {
        String apiHost = "https://presdk.xylink.com";
        String enterpriseId = "94eb7ae1860451435556a46b96a743b0f6e4351f";
        SDKConfigMgr.setServerHost(apiHost);

        String url = "/api/rest/external/v1/conferenceControl/9181318376/meetingStatus?enterpriseId=" + enterpriseId;
        String token = "26ffaa2d014f618af455f79a36fe9e975f62484c9b7354fd844773511686b6da";
        Result<Map> result1 = SdkMethodV1.sdkGet(url, token, Map.class);
        System.out.println(result1);

    }

    /**
     * 单独配置，使用sdk特定方法
     * @throws IOException
     */
    @Test
    public void testSingleConfigWithNormalMethod() throws IOException {
        //        环境信息配置
        String apiHost = "https://presdk.xylink.com";
        String enterpriseId = "94eb7ae1860451435556a46b96a743b0f6e4351f";
        SDKConfigMgr.setServerHost(apiHost);
        String token = "26ffaa2d014f618af455f79a36fe9e975f62484c9b7354fd844773511686b6da";

        ConferenceControlApi conferenceControlApi = new ConferenceControlApi();
        Result<MeetingStatus> meetingStatus = conferenceControlApi.getMeetingStatus(enterpriseId, token, "9181318376");
        System.out.println(meetingStatus);
    }

    /**
     * init配置，使用sdk通用方法，v1版本
     * @throws IOException
     */
    @Test
    public void testInitConfigWithSdkMethod1() throws IOException {
        //环境信息配置
        String apiHost = "https://pre-sdkapi.xylink.com";
        String clientId = "24qquuBJ0PTxWGMPbVaC1faf";
        String clientSecret = "Vat3YlASO7BFd95tTdkokoEjAQnjCF5a";
        String enterpriseId = "94eb7ae1860451435556a46b96a743b0f6e4351f";
        SDKConfigMgr.initSDKConfig(apiHost, clientId, clientSecret, enterpriseId, SignatureVersion.Signature_3_0);

        String url = "/api/rest/external/v1/meetingInfo/9181318376?enterpriseId=" + enterpriseId;
        String token = "26ffaa2d014f618af455f79a36fe9e975f62484c9b7354fd844773511686b6da";
        Result<Map> result1 = SdkMethodV1.sdkGet(url, token, Map.class);
        System.out.println(result1);
    }

    /**
     * init配置，使用sdk通用方法,v2版本
     * @throws IOException
     */
    @Test
    public void testInitConfigWithSdkMethod2() throws IOException {
        //        环境信息配置
        String apiHost = "https://pre-sdkapi.xylink.com";
        String clientId = "24qquuBJ0PTxWGMPbVaC1faf";
        String clientSecret = "Vat3YlASO7BFd95tTdkokoEjAQnjCF5a";
        String enterpriseId = "94eb7ae1860451435556a46b96a743b0f6e4351f";
        SDKConfigMgr.initSDKConfig(apiHost, clientId, clientSecret, enterpriseId);

//        接口信息配置
        String url = "/api/rest/external/v1/meetingInfo/9181318376?enterpriseId=" + enterpriseId;
        String token = "26ffaa2d014f618af455f79a36fe9e975f62484c9b7354fd844773511686b6da";
        Result<Map> result1 = SdkMethodV2.sdkGet(url, Map.class);
//        Result<Map> result1 = SdkMethodV1.sdkGet(url, token, Map.class);
        System.out.println(result1);
    }

    /**
     * init配置，使用sdk特定方法
     * @throws IOException
     */
    @Test
    public void testInitConfigWithNormalMethod() throws IOException {
        //        环境信息配置
        String apiHost = "https://pre-sdkapi.xylink.com";
        String clientId = "24qquuBJ0PTxWGMPbVaC1faf";
        String clientSecret = "Vat3YlASO7BFd95tTdkokoEjAQnjCF5a";
        String enterpriseId = "94eb7ae1860451435556a46b96a743b0f6e4351f";
//        SDKConfigMgr.setServerHost(apiHost);
        SDKConfigMgr.initSDKConfig(apiHost, clientId, clientSecret, enterpriseId);

//        接口信息配置
        String url = "/api/rest/external/v1/meetingInfo/9181318376?enterpriseId=" + enterpriseId;
        String token = "26ffaa2d014f618af455f79a36fe9e975f62484c9b7354fd844773511686b6da";
//        Result<Map> result = SdkMethodV2.sdkGet(url, Map.class);
//        Result<Map> result1 = SdkMethodV1.sdkGet(url, token, Map.class);
        ConferenceControlApi conferenceControlApi = new ConferenceControlApi();
        Result<MeetingStatus> meetingStatus = conferenceControlApi.getMeetingStatus(enterpriseId, token, "9181318376");
        System.out.println(meetingStatus);
    }

    /**
     * 多企业；init配置，使用sdk通用方法，v1版本
     * @throws IOException
     */
    @Test
    public void testMultiEnterpriseInitConfigWithSdkMethod1() throws IOException {
        //pre环境信息配置
        EnterpriseSdkConfig sdkConfig = new EnterpriseSdkConfig();
        sdkConfig.setEnterpriseId("94eb7ae1860451435556a46b96a743b0f6e4351f");
        sdkConfig.setClientId("24qquuBJ0PTxWGMPbVaC1faf");
        sdkConfig.setClientSecret("Vat3YlASO7BFd95tTdkokoEjAQnjCF5a");
        sdkConfig.setServerHost("https://pre-sdkapi.xylink.com");
        //pre环境信息配置
        EnterpriseSdkConfig sdkConfig1 = new EnterpriseSdkConfig();
        sdkConfig1.setEnterpriseId("d03476cd3e5f558fa0edbcf202de80828d8330ad");
        sdkConfig1.setClientId("UGu7xVY62NFeePC8qSnoIiJj");
        sdkConfig1.setClientSecret("CCex9cpYQLl87hMTjaqeCtQ2e5LdgFut");
        sdkConfig1.setServerHost("https://pre-sdkapi.xylink.com");
        //testqa环境信息配置
        EnterpriseSdkConfig sdkConfig2 = new EnterpriseSdkConfig();
        sdkConfig2.setEnterpriseId("50eae31184aca11395c1331555b8f578c34aad1e");
        sdkConfig2.setClientId("npUQDb70RuWFqznfvHvFsWu0");
        sdkConfig2.setClientSecret("1M6EoEf1jejQzlUmAQMPSZIke1KoCoHd");
        sdkConfig2.setServerHost("https://testqa-sdkapi.xylink.com");

        List<EnterpriseSdkConfig> sdkConfigList = new ArrayList<EnterpriseSdkConfig>();
        sdkConfigList.add(sdkConfig);
        sdkConfigList.add(sdkConfig1);
        sdkConfigList.add(sdkConfig2);
        SDKConfigMgr.initSDKConfig(sdkConfigList, null);
//        接口信息配置
        String url = "/api/rest/external/v1/meetingInfo/9181318376?enterpriseId=" + sdkConfig.getEnterpriseId();
        Result<Map> result = SdkMethodV2.sdkGet(url, Map.class);
        System.out.println(result);

        String url1 = "/api/rest/external/v1/meetingInfo/9181718171?enterpriseId=" + sdkConfig1.getEnterpriseId();
        Result<Map> result1 = SdkMethodV2.sdkGet(url1, Map.class);
        System.out.println(result1);

        String url2 = "/api/rest/external/v1/meetingInfo/9090898609?enterpriseId=" + sdkConfig2.getEnterpriseId();
        Result<Map> result2 = SdkMethodV2.sdkGet(url2, Map.class);
        System.out.println(result2);
    }

    @Test
    public void testInitConcurrentLock() throws InterruptedException {
        EnterpriseSdkConfig config = new EnterpriseSdkConfig();
        config.setEnterpriseId("94eb7ae1860451435556a46b96a743b0f6e4351f");
        config.setClientId("24qquuBJ0PTxWGMPbVaC1faf");
        config.setClientSecret("Vat3YlASO7BFd95tTdkokoEjAQnjCF5a");
        config.setServerHost("https://pre-sdkapi.xylink.com");
        List<EnterpriseSdkConfig> sdkConfigList = new ArrayList<EnterpriseSdkConfig>();
        sdkConfigList.add(config);
        SDKConfigMgr.initSDKConfig(sdkConfigList, XyLinkLogType.LogBack);

        final SDKConfig sdkConfig = SDKConfigMgr.getSdkConfig("enterpriseId=94eb7ae1860451435556a46b96a743b0f6e4351f");

        for (int i =0; i< 1000; i++){
            final int finalI = i;
            new Thread(new Runnable() {
                @Override
                public void run() {
                    final Long currentTimeMillis =  System.currentTimeMillis();
                    if (finalI ==0 ){
                        sdkConfig.setAccessTokenExpireIn(currentTimeMillis + 1800000 - 1);
                    }
                    if (sdkConfig.getSignatureVersion().isNewSign()) {
                        if (sdkConfig.getAccessTokenExpireIn() - currentTimeMillis < 10000) {
                            SDKConfigMgr.initAccesstoken(sdkConfig, new Predicate<SDKConfig>() {
                                @Override
                                public boolean apply(SDKConfig config) {
                                    return config.getAccessTokenExpireIn() - currentTimeMillis > 1800000;
                                }
                            }, false);
                        } else if (sdkConfig.getAccessTokenExpireIn() - currentTimeMillis < 1800000) {
                            SchedulerUtil.schedule(new Runnable() {
                                @Override
                                public void run() {
                                    SDKConfigMgr.initAccesstoken(sdkConfig, new Predicate<SDKConfig>() {
                                        public boolean apply(SDKConfig config) {return config.getAccessTokenExpireIn() - currentTimeMillis > 1800000;}
                                    }, true);
                                }
                            }, 0, TimeUnit.MILLISECONDS);
                            System.out.println("当前队数据：" + SchedulerUtil.tasksNnubers());
                        }
                    }
                }
            }).start();
        }
        Thread.sleep(1000);
    }


}
